Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(561)

Unified Diff: remoting/client/plugin/pepper_network_manager.cc

Issue 429253003: Webrtc deps roll. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/plugin/pepper_network_manager.cc
===================================================================
--- remoting/client/plugin/pepper_network_manager.cc (revision 286889)
+++ remoting/client/plugin/pepper_network_manager.cc (working copy)
@@ -12,7 +12,7 @@
#include "ppapi/cpp/net_address.h"
#include "ppapi/cpp/network_list.h"
#include "remoting/client/plugin/pepper_util.h"
-#include "third_party/libjingle/source/talk/base/socketaddress.h"
+#include "third_party/webrtc/base/socketaddress.h"
namespace remoting {
@@ -63,8 +63,8 @@
&PepperNetworkManager::OnNetworkList);
monitor_.UpdateNetworkList(callback);
- // Convert the networks to talk_base::Network.
- std::vector<talk_base::Network*> networks;
+ // Convert the networks to rtc::Network.
+ std::vector<rtc::Network*> networks;
size_t count = list.GetCount();
for (size_t i = 0; i < count; i++) {
std::vector<pp::NetAddress> addresses;
@@ -74,7 +74,7 @@
continue;
for (size_t i = 0; i < addresses.size(); ++i) {
- talk_base::SocketAddress address;
+ rtc::SocketAddress address;
PpNetAddressToSocketAddress(addresses[i], &address);
if (address.family() == AF_INET6 && IPIsSiteLocal(address.ipaddr())) {
@@ -84,7 +84,7 @@
continue;
}
- talk_base::Network* network = new talk_base::Network(
+ rtc::Network* network = new rtc::Network(
list.GetName(i), list.GetDisplayName(i), address.ipaddr(), 0);
network->AddIP(address.ipaddr());
networks.push_back(network);
« no previous file with comments | « remoting/client/plugin/pepper_network_manager.h ('k') | remoting/client/plugin/pepper_packet_socket_factory.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698